@@ -1,7 +1,7 @@
 
 testAdd <- function() {
     ## simple examples of how to add drat information to your session
-    drat::addRepo("CRAN", "http://cran.rstudio.com")
+    drat::addRepo("CRAN", "https://cloud.rstudio.com")
     drat::addRepo(c("eddelbuettel", "RcppCore"))
     
     print(options("repos"))
